@@ -1,7 +1,7 @@
 /*
  * cuefile.c -- cue/toc functions
  *
- * Copyright (C) 2004, 2005, 2006 Svend Sorensen
+ * Copyright (C) 2004, 2005, 2006, 2007, 2013 Svend Sorensen
  * For license terms, see the file COPYING in this distribution.
  */
 
@@ -11,16 +11,17 @@
 #include "cue.h"
 #include "toc.h"
 
-Cd *cf_parse (char *name, int *format)
+Cd *cf_parse(char *name, int *format)
 {
 	FILE *fp = NULL;
 	Cd *cd = NULL;
 
-	if (UNKNOWN == *format)
+	if (UNKNOWN == *format) {
 		if (UNKNOWN == (*format = cf_format_from_suffix(name))) {
-			fprintf(stderr, "%s: unknown format\n", name);
+			fprintf(stderr, "%s: unknown file suffix\n", name);
 			return NULL;
 		}
+	}
 
 	if (0 == strcmp("-", name)) {
 		fp = stdin;
@@ -38,21 +39,23 @@ Cd *cf_parse (char *name, int *format)
 		break;
 	}
 
-	if(stdin != fp)
+	if(stdin != fp) {
 		fclose(fp);
+	}
 
 	return cd;
 }
 
-int cf_print (char *name, int *format, Cd *cd)
+int cf_print(char *name, int *format, Cd *cd)
 {
 	FILE *fp = NULL;
 
-	if (UNKNOWN == *format)
+	if (UNKNOWN == *format) {
 		if (UNKNOWN == (*format = cf_format_from_suffix(name))) {
-			fprintf(stderr, "%s: unknown format\n", name);
+			fprintf(stderr, "%s: unknown file suffix\n", name);
 			return -1;
 		}
+	}
 
 	if (0 == strcmp("-", name)) {
 		fp = stdout;
@@ -60,7 +63,7 @@ int cf_print (char *name, int *format, Cd *cd)
 		fprintf(stderr, "%s: error opening file\n", name);
 		return -1;
 	}
-	
+
 	switch (*format) {
 	case CUE:
 		cue_print(fp, cd);
@@ -70,20 +73,22 @@ int cf_print (char *name, int *format, Cd *cd)
 		break;
 	}
 
-	if(stdout != fp)
+	if(stdout != fp) {
 		fclose(fp);
+	}
 
 	return 0;
 }
 
-int cf_format_from_suffix (char *name)
+int cf_format_from_suffix(char *name)
 {
 	char *suffix;
 	if (0 != (suffix = strrchr(name, '.'))) {
-		if (0 == strcasecmp(".cue", suffix))
+		if (0 == strcasecmp(".cue", suffix)) {
 			return CUE;
-		else if (0 == strcasecmp(".toc", suffix))
+		} else if (0 == strcasecmp(".toc", suffix)) {
 			return TOC;
+		}
 	}
 
 	return UNKNOWN;
